@@ -27,16 +27,17 @@ class StreamReceiver:
     """
 
     def __init__(self, bufsize=1, winsize=1, stream_name=None):
-        self._winsize = StreamReceiver._check_winsize(winsize)
-        self._bufsize = StreamReceiver._check_bufsize(bufsize, winsize)
-        self._stream_name = StreamReceiver._check_format_stream_name(
-            stream_name)
         self._connected = False
+        self._streams = dict()
         self._acquisition_threads = dict()
         self._mne_infos = dict()
-        self.connect()
 
-    def connect(self, timeout=5, force=False):
+        self._winsize = StreamReceiver._check_winsize(winsize)
+        self._bufsize = StreamReceiver._check_bufsize(bufsize, self._winsize)
+        self.connect(stream_name)
+
+    @fill_doc
+    def connect(self, stream_name=None, timeout=5, force=False):
         """
         Search for the available streams on the LSL network and connect to the
         appropriate ones. If a LSL stream fullfills the requirements (name...),
@@ -47,6 +48,7 @@ class StreamReceiver:
 
         Parameters
         ----------
+        %(stream_name)s
         timeout : `int` | `float`
             Timeout duration in seconds after which the search is abandonned.
         force : `bool`
@@ -55,6 +57,13 @@ class StreamReceiver:
         """
         if not force and self._connected:
             return True
+
+        stream_name = StreamReceiver._check_format_stream_name(stream_name)
+        if stream_name is not None and force and self._connected:
+            self._stream_name.extend(stream_name)
+        else:
+            self._stream_name = stream_name
+
         self._connected = False
         self._streams = dict()
 
@@ -134,6 +143,9 @@ class StreamReceiver:
             Servers' name or list of servers' name to disconnect from.
             If `None`, disconnect from all streams.
         """
+        if not self._connected:
+            return
+
         stream_name = StreamReceiver._check_format_stream_name(stream_name)
         if stream_name is None:
             stream_name = list(self._streams)
@@ -145,6 +157,9 @@ class StreamReceiver:
             self._streams[stream]._inlet.close_stream()
             del self._streams[stream]
             del self._acquisition_threads[stream]
+            if self._stream_name is not None:
+                idx = self._stream_name.index(stream)
+                del self._stream_name[idx]
 
         if len(self._streams) == 0:
             self._connected = False
@@ -154,9 +169,8 @@ class StreamReceiver:
         Read data from the streams and fill their buffer using threading.
         """
         if not self._connected:
-            logger.error(
-                'The Stream Receiver is not connected to any streams. ')
-            raise RuntimeError
+            raise RuntimeError('StreamReceiver is not connected to any '
+                               'streams.')
 
         for stream in self._streams:
             if self._acquisition_threads[stream] is not None and \
@@ -190,42 +204,33 @@ class StreamReceiver:
         %(receiver_get_unit)s
         """
         if not self._connected:
-            logger.error(
-                'The Stream Receiver is not connected to any streams. ')
-            raise RuntimeError
+            raise RuntimeError('StreamReceiver is not connected to any '
+                               'streams.')
 
         if stream_name is None and len(self._streams) == 1:
             stream_name = list(self._streams)[0]
         elif stream_name is None and len(self._streams) > 1:
-            logger.error('The Stream Receiver is connected to multiple '
-                         'streams. Please provide the stream_name argument. ')
-            raise RuntimeError
+            raise RuntimeError(
+                'StreamReceiver is connected to multiple streams. Please '
+                'provide the stream_name argument.')
 
         try:
             self._acquisition_threads[stream_name].join()
-        except KeyError as error:
-            logger.error(
-                f"The Stream Receiver is not connected to '{stream_name}'.",
-                exc_info=True)
-            raise error
-        except AttributeError as error:
-            logger.warning(
-                '.acquire() must be called before .get_buffer().',
-                exc_info=True)
-            raise error
+        except KeyError:
+            raise KeyError("StreamReceiver is not connected to '%s'."
+                           % stream_name)
+        except AttributeError:
+            raise AttributeError(
+                '.acquire() must be called before .get_window().')
 
         winsize = self._streams[stream_name].buffer.winsize
-        try:
-            window = np.array(self._streams[
-                stream_name].buffer.data[-winsize:])
-            timestamps = np.array(self._streams[
-                stream_name].buffer.timestamps[-winsize:])
-        except IndexError:
+        window = np.array(self._streams[stream_name].buffer.data[-winsize:])
+        timestamps = np.array(self._streams[
+            stream_name].buffer.timestamps[-winsize:])
+        if len(timestamps) != winsize:
             logger.warning(
-                f"The buffer of {stream_name} does not contain enough "
-                "samples. Returning the available samples.")
-            window = np.array(self._streams[stream_name].buffer.data)
-            timestamps = np.array(self._streams[stream_name].buffer.timestamps)
+                'The buffer of %s does not contain enough samples. Returning '
+                'the available samples.', stream_name)
 
         if len(timestamps) > 0:
             if bool(return_raw) and self._mne_infos[stream_name] is not None:
@@ -234,13 +239,13 @@ class StreamReceiver:
                 window._filenames = [f'BSL {stream_name}']
             elif bool(return_raw) and self._mne_infos[stream_name] is None:
                 logger.warning(
-                    f'The LSL stream {stream_name} can not be converted to'
-                    'MNE raw instance. Returning numpy arrays.')
+                    'The LSL stream %s can not be converted to MNE raw '
+                    'instance. Returning numpy arrays.', stream_name)
         else:
-            if verbose:
+            if verbose:  # Needed for StreamViewer
                 logger.warning(
-                    f'The LSL stream {stream_name} did not return any data.'
-                    'Returning empty numpy arrays.')
+                    'The LSL stream %s did not return any data.'
+                    'Returning empty numpy arrays.', stream_name)
             window = np.empty((0, len(self._streams[stream_name].ch_list)))
             timestamps = np.array([])
 
@@ -268,26 +273,24 @@ class StreamReceiver:
         %(receiver_get_unit)s
         """
         if not self._connected:
-            logger.error(
-                'The Stream Receiver is not connected to any streams. ')
-            raise RuntimeError
+            raise RuntimeError('StreamReceiver is not connected to any '
+                               'streams.')
 
         if stream_name is None and len(self._streams) == 1:
             stream_name = list(self._streams)[0]
         elif stream_name is None and len(self._streams) > 1:
-            logger.error('The Stream Receiver is connected to multiple '
-                         'streams. Please provide the stream_name argument. ')
-            raise RuntimeError
+            raise RuntimeError(
+                'StreamReceiver is connected to multiple streams. Please '
+                'provide the stream_name argument.')
 
         try:
             self._acquisition_threads[stream_name].join()
-        except KeyError as error:
-            logger.error(
-                f"The Stream Receiver is not connected to '{stream_name}'.")
-            raise error
-        except AttributeError as error:
-            logger.warning('.acquire() must be called before .get_buffer().')
-            raise error
+        except KeyError:
+            raise KeyError("StreamReceiver is not connected to '%s'."
+                           % stream_name)
+        except AttributeError:
+            raise AttributeError(
+                '.acquire() must be called before .get_buffer().')
 
         window = np.array(self._streams[stream_name].buffer.data)
         timestamps = np.array(self._streams[stream_name].buffer.timestamps)
@@ -298,13 +301,13 @@ class StreamReceiver:
                 window._filenames = [f'BSL {stream_name}']
             elif bool(return_raw) and self._mne_infos[stream_name] is None:
                 logger.warning(
-                    f'The LSL stream {stream_name} can not be converted to'
-                    'MNE raw instance. Returning numpy arrays.')
+                    'The LSL stream %s can not be converted to MNE raw '
+                    'instance. Returning numpy arrays.', stream_name)
         else:
-            if verbose:
+            if verbose:  # Needed for StreamViewer
                 logger.warning(
-                    f'The LSL stream {stream_name} did not return any data.'
-                    'Returning empty numpy arrays.')
+                    'The LSL stream %s did not return any data.'
+                    'Returning empty numpy arrays.', stream_name)
             window = np.empty((0, len(self._streams[stream_name].ch_list)))
             timestamps = np.array([])
 
@@ -331,34 +334,64 @@ class StreamReceiver:
             self._streams[stream].buffer.reset_buffer()
 
     # --------------------------------------------------------------------
-    @staticmethod
-    def _check_winsize(winsize):
-        """
-        Check that winsize is positive.
-        """
-        if winsize <= 0:
-            logger.error(f'Invalid window size {winsize}.')
-            raise ValueError
+    def __del__(self):
+        """Destructor method."""
+        self.disconnect()
 
-        return winsize
+    def __repr__(self):
+        """Representation of the instance."""
+        status = 'ON' if self._connected else 'OFF'
+        if self._connected:
+            streams = str(tuple(self._streams))
+        else:
+            streams = '()' if self._stream_name is None \
+                else str(tuple(self._stream_name))
+        repr_str = f'<Receiver: {streams} | {status} | ' + \
+                   f'buf: {self._bufsize}s - win: {self._winsize}s>'
+        return repr_str
 
+    # --------------------------------------------------------------------
     @staticmethod
     def _check_bufsize(bufsize, winsize):
         """
         Check that bufsize is positive and bigger than the winsize.
         """
-        if bufsize <= 0:
-            logger.error(f'Invalid buffer size {bufsize}.')
-            raise ValueError
-
-        if bufsize < winsize:
-            logger.error(
-                f'Buffer size  {bufsize:.1f} is smaller than window size. '
-                f'Setting to {winsize:.1f}')
-            bufsize = winsize
+        if isinstance(bufsize, (int, float)):
+            bufsize = float(bufsize)
+            if bufsize <= 0:
+                raise ValueError(
+                    'Argument bufsize must be a strictly positive int or a '
+                    'float. Provided: %s' % bufsize)
+            if bufsize < winsize:
+                logger.error(
+                    'Buffer size %.2f is smaller than window size. '
+                    'Setting to %.2f.', bufsize, winsize)
+                bufsize = winsize
+        else:
+            raise TypeError(
+                'Argument bufsize must be a strictly positive int or a float. '
+                'Provided: %s' % type(bufsize))
 
         return bufsize
 
+    @staticmethod
+    def _check_winsize(winsize):
+        """
+        Check that winsize is positive.
+        """
+        if isinstance(winsize, (int, float)):
+            winsize = float(winsize)
+            if winsize <= 0:
+                raise ValueError(
+                    'Argument winsize must be a strictly positive int or a '
+                    'float. Provided: %s' % winsize)
+        else:
+            raise TypeError(
+                'Argument winsize must be a strictly positive int or a float. '
+                'Provided: %s' % type(winsize))
+
+        return winsize
+
     @staticmethod
     def _check_format_stream_name(stream_name):
         """
@@ -367,81 +400,57 @@ class StreamReceiver:
         if isinstance(stream_name, (list, tuple)):
             stream_name = list(stream_name)
             if not all(isinstance(name, str) for name in stream_name):
-                logger.error(
-                    'Stream name must be a string or a list of strings.')
-                raise TypeError
+                raise TypeError(
+                    'Argument stream_name must be a string or a list of '
+                    'strings. Provided: %s' % stream_name)
         elif isinstance(stream_name, str):
             stream_name = [stream_name]
+        elif stream_name is None:
+            stream_name = None
         else:
+            logger.error(
+                'Argument stream_name must be a string or a list of strings. '
+                'Provided: %s -> Changing to None.', stream_name)
             stream_name = None
 
         return stream_name
 
     # --------------------------------------------------------------------
-    @property
-    def bufsize(self):
-        """
-        Buffer's size ``[sec]``.
-
-        :setter: Checks that the bufsize is valid.
-        :type: `int` | `float`
-        """
-        return self._bufsize
-
-    @bufsize.setter
-    def bufsize(self, bufsize):
-        self._bufsize = StreamReceiver._check_bufsize(bufsize, self._winsize)
-        self.connect(force=True)
-
     @property
     def winsize(self):
         """
         Window's size ``[sec]``.
 
-        :setter: Checks that the winsize is smaller than the bufsize.
         :type: `int` | `float`
         """
         return self._winsize
 
-    @winsize.setter
-    def winsize(self, winsize):
-        self._winsize = StreamReceiver._check_winsize(winsize)
-        self._bufsize = StreamReceiver._check_bufsize(self._bufsize, winsize)
-        self.connect(force=True)
+    @property
+    def bufsize(self):
+        """
+        Buffer's size ``[sec]``.
+
+        :type: `int` | `float`
+        """
+        return self._bufsize
 
     @property
     def stream_name(self):
         """
         Connected stream's name.
 
-        :setter: Try to connect to the new stream(s), revert to old stream(s)
-            if failed.
-        :type: `list` | `None`
+        :type: `None` | `list`
         """
         return self._stream_name
 
-    @stream_name.setter
-    def stream_name(self, stream_name):
-        old_stream_name = self._stream_name
-        self._stream_name = StreamReceiver._check_format_stream_name(
-            stream_name)
-        self.connect(force=True)
-
-        if not self._connected:
-            logger.error(
-                'The Stream Receiver could not connect to the new stream '
-                'names. Reconnecting to the old stream names.')
-            self._stream_name = old_stream_name
-            self.connect(force=True)
-
     @property
-    def streams(self):
+    def connected(self):
         """
-        Connected streams dictionary ``{stream_name: _Stream}``.
+        Connected status.
 
-        :type: `dict`
+        :type: `bool`
         """
-        return self._streams
+        return self._connected
 
     @property
     def mne_infos(self):
@@ -453,10 +462,10 @@ class StreamReceiver:
         return self._mne_infos
 
     @property
-    def connected(self):
+    def streams(self):
         """
-        Connected status.
+        Connected streams dictionary ``{stream_name: _Stream}``.
 
-        :type: `bool`
+        :type: `dict`
         """
-        return self._connected
+        return self._streams
