@@ -19,18 +19,14 @@ stream_name : `list` | `str` | `None`
 # Stream Receiver
 docdict['receiver_get_stream_name'] = """
 stream_name : `str` | `None`
-    Name of the stream to extract from.
-    Can be set to `None` if the `~bsl.StreamReceiver` is connected to a single
-    stream."""
+    Name of the stream from which data is retrieved.
+    Can be set to `None` (default) if the `~bsl.StreamReceiver` is connected to
+    a single stream."""
 docdict['receiver_get_return_raw'] = """
 return_raw : `bool`
     By default (``False``), data is returned as a `~numpy.array` of shape
-    ``(samples, channels)`. If set to ``True``, the `~bsl.StreamReceiver` will
-    attempt to return MNE `~mne.io.Raw` instances."""
-docdict['receiver_get_verbose'] = """
-verbose : `bool`
-    If ``True`` (default), a warning will be issued when the method returns
-    empty `~numpy.array`. If ``False``, this warning will be skipped."""
+    ``(samples, channels)``. If set to ``True``, the `~bsl.StreamReceiver` will
+    attempt to return data as a MNE `~mne.io.Raw` instances."""
 docdict['receiver_data'] = """
 data : `~numpy.array`
     Data ``(samples, channels)``."""
@@ -38,13 +34,17 @@ docdict['receiver_timestamps'] = """
 timestamps : `~numpy.array`
     Data's timestamps ``(samples, )``."""
 docdict['receiver_get_unit'] = """
-Returns a raw data array in the unit streamed by the LSL outlet. For
-conversion, the corresponding multiplier must be set for each stream, with e.g.
-for a stream in uV to convert to V:
+Returns a raw data array in the unit streamed by the LSL outlet. For conversion
+the corresponding scaling factor must be set for each stream, with e.g. for a
+stream in uV to convert to V:
 
 .. code-block:: python
 
-    sr.streams['stream_to_convert'].multiplier = 1e-6"""
+    sr.streams['stream_to_convert'].scaling_factor = 1e-6"""
+docdict['receiver_get_verbose'] = """
+verbose : `bool`
+    If ``True`` (default), a warning will be issued when the method returns
+    empty `~numpy.array`. If ``False``, this warning will be skipped."""
 docdict['receiver_bufsize'] = """
 bufsize : `int` | `float`
     Buffer's size ``[secs]``. ``MAX_BUF_SIZE`` (def: 1-day) is the maximum
@@ -64,14 +64,25 @@ tslist : list
 # -----------------------------------------------
 # Stream Recorder
 docdict['recorder_record_dir'] = """
-record_dir : `str` | `~pathlib.Path`
-    Directory where the data will be saved."""
+record_dir : `None` | `str` | `~pathlib.Path`
+    Path to the directory where data will be saved.
+
+    .. note:: If the directory does not exist, it is created.
+
+    .. note:: If None, the current working directory is used.
+"""
 docdict['recorder_fname'] = """
-fname : `str` | `None`
-    File name stem used to create the files:
-        PCL: ``'{fname}-[stream]-raw.pcl'``
-        FIF: ``'{fname}-[stream]-raw.fif'``
-        (optional) SOFTWARE trigger events: ``'{fname}-eve.txt'``"""
+fname : `None` | `str`
+    File name stem used to create the files. The StreamRecorder creates 2 files
+    plus an optional third if a software trigger was used, respecting the
+    following naming:
+
+    .. code-block:: python
+
+        PCL: '{fname}-[stream_name]-raw.pcl'
+        FIF: '{fname}-[stream_name]-raw.fif'
+        (optional) SOFTWARE trigger events: '{fname}-eve.txt'
+"""
 docdict['recorder_fif_subdir'] = """
 fif_subdir : `bool`
     If ``True``, the ``.pcl`` files are converted to ``.fif`` in a
@@ -81,25 +92,6 @@ verbose : `bool`
     If ``True``, a timer showing since when the recorder started is displayed
     every seconds."""
 
-# -----------------------------------------------
-# Stream Player
-docdict['player_stream_name'] = """
-stream_name : `str`
-    Stream's server name, displayed on LSL network."""
-docdict['player_fif_file'] = """
-fif_file : `str` | `~pathlib.Path`
-    Path to the ``.fif`` file to play."""
-docdict['player_chunk_size'] = """
-chunk_size : `int`
-    Number of samples to send at once (usually ``16-32`` is good enough)."""
-docdict['player_repeat'] = """
-repeat : `int`
-    Number of times to replay the data (``default=inf``)."""
-docdict['player_high_resolution'] = """
-high_resolution : `bool`
-    If ``True``, it uses `~time.perf_counter()` instead of `~time.sleep()` for
-    higher time resolution. However, it uses more CPU."""
-
 # -----------------------------------------------
 # Stream Viewer
 
@@ -156,11 +148,6 @@ delay : `int`
     Delay in milliseconds until which a new trigger cannot be sent."""
 docdict['trigger_lpt_usb2lpt_link'] = 'https://www-user.tu-chemnitz.de/~heha/bastelecke/Rund%20um%20den%20PC/USB2LPT/'
 docdict['trigger_lpt_arduino2lpt_link'] = 'https://github.com/fcbg-hnp/arduino-trigger'
-docdict['trigger_file'] = """
-trigger_file : `str` | `~pathlib.Path` | `None`
-    Path to the ``.ini`` file containing the table converting event numbers
-    into event strings."""
-
 
 # ------------------------- Documentation functions --------------------------
 docdict_indented = dict()
